==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Stvori mrežu od oblika ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Pretvori oblik u mrežu</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation type="unfinished">Create section from mesh and plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Odsječak</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation type="unfinished">Trim mesh with a plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation type="unfinished">Trims a mesh with a plane</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Stvoriti</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Brisanje</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Otkazati</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ni jedan vrh nije odabran</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Žica</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Kriva aproksimacija</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation type="unfinished">Continuity</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Počni</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Mozaik</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Oblici</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation type="unfinished">Meshing options</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation type="unfinished">Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation type="unfinished">Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Odredi segmente po boji naličja</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Relativno odstupanje površine</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maksimalna duljina ruba:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation type="unfinished">Fineness:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Jako grubo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation type="unfinished">Coarse</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation type="unfinished">Moderate</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation type="unfinished">Fine</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Jako fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Korisnički određeno</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation type="unfinished">Mesh size grading:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation type="unfinished">Elements per edge:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation type="unfinished">Elements per curvature radius:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation type="unfinished">Optimize surface</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation type="unfinished">Second order elements</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation type="unfinished">Quad dominated</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Postavke</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odstupanje površine:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. duljina ruba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Prvo daberite oblik za umrežavanje.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Ne postoji takav dokument '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation type="unfinished">Select plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation type="unfinished">Select plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation type="unfinished">Please select a plane at which you trim the mesh.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mrežasti Oblik</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Krivulja na mreži...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na mreži</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Stvori mrežu od oblika ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Pretvori oblik u mrežu</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Stvori presjek iz mreže i ravnine</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Odsječak</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Obrezivanje mreže s ravninom</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Obrezuje mrežu s ravninom</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Stvoriti</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Zatvori žicu</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Brisanje</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Otkazati</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Izabrana pogrešna mreža</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Ni jedan vrh nije odabran</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na mreži</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Žica</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Tolerancija kod privuci na vrhove</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Granična vrijednost razdjeljivanja</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Kriva aproksimacija</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Odstupanje na mreži</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Kontinuitet</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Maksimalni Stupanj krivulje</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Počni</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Mozaik</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Oblici</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Opcije mreže</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Odredi segmente po boji naličja</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Dodaje boju lica na mrežu</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Kutna odstupanja:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Relativno odstupanje površine</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Maksimalna duljina ruba:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation type="unfinished">Fineness:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Jako grubo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation type="unfinished">Coarse</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation type="unfinished">Moderate</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation type="unfinished">Fine</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Jako fino</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Korisnički određeno</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Veličina Mreže stupnjevanje:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Elemenata po rubu:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Elemenata po radijusu zakrivljenosti:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimizirati površinu</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Drugi red elemenata</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Quad dominira</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Postavke</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Odstupanje površine:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Max. duljina ruba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Prvo daberite oblik za umrežavanje.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Ne postoji takav dokument '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Odaberite ravninu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Molimo odaberite ravninu na kojoj se dijeli mreža.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Odaberite ravninu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Molimo odaberite ravninu na kojoj se skraćuje mreža.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Skraćivanje sa ravninom</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Odaberite stranu koju želite zadržati.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Unutrašnji</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Vanjski</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Razdjeli</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Mrežasti Oblik</translation>
    </message>
  </context>
</TS>
